ForeCA-package: Implementation of Forecastable Component Analysis (ForeCA)

ForeCA-packageR Documentation

Implementation of Forecastable Component Analysis (ForeCA)

Description

Forecastable Component Analysis (ForeCA) is a novel dimension reduction technique for multivariate time series \mathbf{X}_t. ForeCA finds a linar combination y_t = \mathbf{X}_t \mathbf{v} that is easy to forecast. The measure of forecastability \Omega(y_t) (Omega) is based on the entropy of the spectral density f_y(\lambda) of y_t: higher entropy means less forecastable, lower entropy is more forecastable.

The main function foreca runs ForeCA on a multivariate time series \mathbf{X}_t.

Consult NEWS.md for a history of release notes.

Author(s)

Maintainer: Georg M. Goerg im@gmge.org

References

Goerg, G. M. (2013). “Forecastable Component Analysis”. Journal of Machine Learning Research (JMLR) W&CP 28 (2): 64-72, 2013. Available at https://proceedings.mlr.press/v28/goerg13.html.

See Also

Useful links:

Examples

XX <- ts(diff(log(EuStockMarkets)))
Omega(XX)

plot(log10(lynx))
Omega(log10(lynx))

## Not run: 
ff <- foreca(XX, n.comp = 4)
ff
plot(ff)
summary(ff)

## End(Not run)


ForeCA documentation built on Aug. 23, 2026, 9:09 a.m.